@@ -1,4 +1,4 @@
-package Plack::Server::Coor;
+package Plack::Server::Coro;
 use base qw(Plack::Handler::Corona);
 
 our $VERSION = '0.1002';
